import logging

import requests

logger = logging.getLogger(__name__)


def ping_cronhub(ping_url, config_filename, dry_run, state):
    '''
    Ping the given Cronhub URL, substituting in the state string. Use the given configuration
    filename in any log entries. If this is a dry run, then don't actually ping anything.
    '''
    if not ping_url:
        logger.debug('{}: No Cronhub hook set'.format(config_filename))
        return

    dry_run_label = ' (dry run; not actually pinging)' if dry_run else ''
    formatted_state = '/{}/'.format(state)
    ping_url = ping_url.replace('/start/', formatted_state).replace('/ping/', formatted_state)

    logger.info('{}: Pinging Cronhub {}{}'.format(config_filename, state, dry_run_label))
    logger.debug('{}: Using Cronhub ping URL {}'.format(config_filename, ping_url))

    if not dry_run:
        logging.getLogger('urllib3').setLevel(logging.ERROR)
        requests.get(ping_url)



import logging

import requests

logger = logging.getLogger(__name__)


def ping_healthchecks(ping_url_or_uuid, config_filename, dry_run, append=None):
    '''
    Ping the given Healthchecks URL or UUID, appending the append string if any. Use the given
    configuration filename in any log entries. If this is a dry run, then don't actually ping
    anything.
    '''
    if not ping_url_or_uuid:
        logger.debug('{}: No Healthchecks hook set'.format(config_filename))
        return

    ping_url = (
        ping_url_or_uuid
        if ping_url_or_uuid.startswith('http')
        else 'https://hc-ping.com/{}'.format(ping_url_or_uuid)
    )
    dry_run_label = ' (dry run; not actually pinging)' if dry_run else ''

    if append:
        ping_url = '{}/{}'.format(ping_url, append)

    logger.info(
        '{}: Pinging Healthchecks{}{}'.format(
            config_filename, ' ' + append if append else '', dry_run_label
        )
    )
    logger.debug('{}: Using Healthchecks ping URL {}'.format(config_filename, ping_url))

    if not dry_run:
        logging.getLogger('urllib3').setLevel(logging.ERROR)
        requests.get(ping_url)



import logging

import requests

logger = logging.getLogger(__name__)


def ping_cronitor(ping_url, config_filename, dry_run, append):
    '''
    Ping the given Cronitor URL, appending the append string. Use the given configuration filename
    in any log entries. If this is a dry run, then don't actually ping anything.
    '''
    if not ping_url:
        logger.debug('{}: No Cronitor hook set'.format(config_filename))
        return

    dry_run_label = ' (dry run; not actually pinging)' if dry_run else ''
    ping_url = '{}/{}'.format(ping_url, append)

    logger.info('{}: Pinging Cronitor {}{}'.format(config_filename, append, dry_run_label))
    logger.debug('{}: Using Cronitor ping URL {}'.format(config_filename, ping_url))

    if not dry_run:
        logging.getLogger('urllib3').setLevel(logging.ERROR)
        requests.get(ping_url)
